@@ -13,7 +13,10 @@ class DDLexer:
         self.current_pos = -1
         self.next_char()
         self.variable_prefixes = ['user', 'conv', 'dialog', 'wf']
-        self.system_variables = ['conv.__utterance__', 'conv.__user__']
+        # 'conv.__entities__' and 'conv.__nlu_response__' are not listed here as
+        # their type is List[] and Map{} respectively and we don't want people to use
+        # them in conditions
+        self.system_variables = ['conv.__utterance__', 'conv.__username__', 'conv.__intent__']
 
     # processes the next character
     def next_char(self):
